@@ -1,27 +1,26 @@
 #ifndef CO_AUTOCORR_H
 #define CO_AUTOCORR_H
 
-#if __cplusplus
-#   include <complex>
-typedef std::complex< double > cplx;
-#else
-#   include <complex.h>
-#if defined(__GNUC__) || defined(__GNUG__)
-typedef double complex cplx;
-#elif defined(_MSC_VER)
-typedef _Dcomplex cplx;
-#endif
-#endif
-
 #include <math.h>
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 #include "stats.h"
 #include "fft.h"
+#if __cplusplus
+#   include <complex>
+#else
+#   include <complex.h>
+#endif
 
 extern int nextpow2(int n);
-extern void dot_multiply(cplx a[], cplx b[], int size);
+
+#if defined(__GNUC__) || defined(__GNUG__)
+extern void dot_multiply(double _Complex a[], double _Complex b[], int size);
+#elif defined(_MSC_VER)
+extern void dot_multiply(_Dcomplex a[], _Dcomplex b[], int size);
+#endif
+
 extern double * CO_AutoCorr(const double y[], const int size, const int tau[], const int tau_size);
 extern double * co_autocorrs(const double y[], const int size);
 extern int co_firstzero(const double y[], const int size, const int maxtau);
